@@ -139,6 +139,24 @@ class TestRPCDispatcher(unittest.TestCase):
         self.assertEqual(jsondict['id'], 1)
         self.assertEqual(jsondict['result'], 3)
         
+    def test_register_methods(self):
+        self.d.register_rpcmethods(['rpc4django.tests.testmod'])
+        
+        jsontxt = '{"params":[3,1],"method":"subtract","id":1}'
+        resp = self.d.jsondispatch(jsontxt)
+        jsondict = json.loads(resp)
+        self.assertTrue(jsondict['error'] is None)
+        self.assertEqual(jsondict['id'], 1)
+        self.assertEqual(jsondict['result'], 2)
+        
+        jsontxt = '{"params":[3,2],"method":"power","id":99}'
+        resp = self.d.jsondispatch(jsontxt)
+        jsondict = json.loads(resp)
+        self.assertTrue(jsondict['error'] is None)
+        self.assertEqual(jsondict['id'], 99)
+        self.assertEqual(jsondict['result'], 9)
+        
+        
     def test_kwargs(self):
         self.d.register_method(self.kwargstest)
         
